Learn R Programming

TransModel (version 2.3)

summary.TransModel: Summary results for fitting the linear transformation model

Description

A summary table contains the coefficient estimates, standard errors, test statistics and p values in the linear transformation model.

Usage

# S3 method for TransModel
summary(object, ...)

Arguments

object

An object returned from the function TransModel.

…

Other auguments to be specified for the summary function.

Value

coefficients

The summary table.

Examples

Run this code
# NOT RUN {
data(veteran)
fit<-TransModel(Surv(time,status)~karno+as.factor(celltype),data=veteran,r=0,subset=(prior==0))
summary(fit)

fit0<-TransModel(Surv(time,status)~1,data=veteran,r=0,subset=(prior==0))  #the null model
summary(fit0)
# }

Run the code above in your browser using DataLab